==> freecad_0.13.2935-dfsg.orig.tar.xz: freecad-0.13.2935-dfsg/src/Mod/Image/Gui/Resources/translations/Image_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Image</source>
      <translation>Obrázek</translation>
    </message>
    <message>
      <source>Create image plane...</source>
      <translation>Vytvoření roviny obrázku...</translation>
    </message>
    <message>
      <source>Create a planar image in the 3D space</source>
      <translation>Vytvoří roviný obrázek ve 3D prostoru</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation>create a planar image in the 3D space</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <source>Image</source>
      <translation>Obrázek</translation>
    </message>
    <message>
      <source>Open...</source>
      <translation>Otevřít...</translation>
    </message>
    <message>
      <source>Open image view</source>
      <translation>Otevřít náhled obrázku</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+318"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>Nedefinovaný typ barvy prostoru pro zobrazení obrázku</translation>
    </message>
    <message>
      <source>Image pixel format</source>
      <translation>Formát bodu obrázku</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+77"/>
      <source>&amp;Fit image</source>
      <translation>Přizpůsobit obrázek</translation>
    </message>
    <message>
      <source>Stretch the image to fit the view</source>
      <translation>Přizpůsobit obrázek velikosti pohledu</translation>
    </message>
    <message>
      <source>&amp;1:1 scale</source>
      <translation>měřítko &amp;1:1</translation>
    </message>
    <message>
      <source>Display the image at a 1:1 scale</source>
      <translation>Zobrazit obrázek v měřítku 1:1</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation>&amp;Original color</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation>Display the image with its original color(s)</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation>&amp;Brightened color</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation>Display the image with brightened color(s)</translation>
    </message>
    <message>
      <source>Standard</source>
      <translation>Standard</translation>
    </message>
    <message>
      <source>Ready...</source>
      <translation>Připraven...</translation>
    </message>
    <message>
      <source>grey</source>
      <translation>šedá</translation>
    </message>
    <message>
      <source>zoom</source>
      <translation>zvětšení</translation>
    </message>
    <message>
      <source>outside image</source>
      <translation>okolí obrázku</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation>Image viewer</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="+106"/>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Obrázky (*.png *.xpm *.jpg *.bmp)</translation>
    </message>
    <message>
      <source>Choose an image file to open</source>
      <translation>Vyber soubor obrázku pro otevření</translation>
    </message>
    <message>
      <source>Images</source>
      <translation>Obrázky</translation>
    </message>
    <message>
      <source>All files</source>
      <translation>Všechny soubory</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>Chyba při otevírání obrázku</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>Nemohu načist vybraný obrázek</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Obrázek</translation>
    </message>
  </context>
</TS>

==> freecad_0.14.3702+dfsg.orig.tar.xz: freecad-0.14.3702/src/Mod/Image/Gui/Resources/translations/Image_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs" sourcelanguage="en">
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+94"/>
      <source>Image</source>
      <translation>Obrázek</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create image plane...</source>
      <translation>Vytvoření roviny obrázku...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a planar image in the 3D space</source>
      <translation>Vytvoří roviný obrázek ve 3D prostoru</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation type="obsolete">create a planar image in the 3D space</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location line="-44"/>
      <source>Image</source>
      <translation>Obrázek</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open...</source>
      <translation>Otevřít...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open image view</source>
      <translation>Otevřít náhled obrázku</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+326"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>Nedefinovaný typ barvy prostoru pro zobrazení obrázku</translation>
    </message>
    <message>
      <location line="-1"/>
      <source>Image pixel format</source>
      <translation>Formát bodu obrázku</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="+14"/>
      <source>Choose orientation</source>
      <translation type="unfinished">Choose orientation</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Image plane</source>
      <translation type="unfinished">Image plane</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>XY-Plane</source>
      <translation type="unfinished">XY-Plane</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>XZ-Plane</source>
      <translation type="unfinished">XZ-Plane</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>YZ-Plane</source>
      <translation type="unfinished">YZ-Plane</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Reverse direction</source>
      <translation type="unfinished">Reverse direction</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Offset:</source>
      <translation type="unfinished">Offset:</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+77"/>
      <source>&amp;Fit image</source>
      <translation>Přizpůsobit obrázek</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Stretch the image to fit the view</source>
      <translation>Přizpůsobit obrázek velikosti pohledu</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;1:1 scale</source>
      <translation>měřítko &amp;1:1</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>Zobrazit obrázek v měřítku 1:1</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation type="obsolete">&amp;Original color</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation type="obsolete">Display the image with its original color(s)</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation type="obsolete">&amp;Brightened color</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation type="obsolete">Display the image with brightened color(s)</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Standard</source>
      <translation>Standard</translation>
    </message>
    <message>
      <location line="+13"/>
      <source>Ready...</source>
      <translation>Připraven...</translation>
    </message>
    <message>
      <location line="+375"/>
      <source>grey</source>
      <translation>šedá</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+3"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <source>zoom</source>
      <translation>zvětšení</translation>
    </message>
    <message>
      <location line="-62"/>
      <location line="+10"/>
      <location line="+15"/>
      <location line="+16"/>
      <location line="+16"/>
      <source>outside image</source>
      <translation>okolí obrázku</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation type="obsolete">Image viewer</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="+117"/>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Obrázky (*.png *.xpm *.jpg *.bmp)</translation>
    </message>
    <message>
      <location line="-99"/>
      <location line="+41"/>
      <location line="+57"/>
      <source>Choose an image file to open</source>
      <translation>Vyber soubor obrázku pro otevření</translation>
    </message>
    <message>
      <location line="-105"/>
      <location line="+41"/>
      <source>Images</source>
      <translation>Obrázky</translation>
    </message>
    <message>
      <location line="-36"/>
      <location line="+41"/>
      <source>All files</source>
      <translation>Všechny soubory</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Error open image</source>
      <translation>Chyba při otevírání obrázku</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Could not load the choosen image</source>
      <translation>Nemohu načist vybraný obrázek</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Obrázek</translation>
    </message>
  </context>
</TS>
